import Vue from 'vue';
import router from '@/router';
import {ResetArrayMethods, ResetObjectMethods} from '@/modules/reset-methods';
import App from './App.vue';
import store from '@/store';
import WmsLoader from '@/components/wms-loader';
import WmsTranslation from '@/modules/wms-translation';
import ApiPlugin from '@/modules/wms-api';
import BootstrapVue from 'bootstrap-vue';
import './assets/css/bootstrap.css';
import 'bootstrap-vue/dist/bootstrap-vue.css';
import 'element-ui/lib/theme-chalk/date-picker.css';

import config from '@/configuration/config';
import Modal from './components/modal/index.js';
import 'element-ui/lib/theme-chalk/select.css';
import {ROOT_ID} from '@/configuration/constants';

// reset methods after use prototype.js
ResetArrayMethods(['map']);
ResetObjectMethods(['keys']);

Vue.use(WmsTranslation);
Vue.use(ApiPlugin);
Vue.use(BootstrapVue);
Vue.use(Modal);

window.wmsApp = new Vue({
    el: ROOT_ID,
    router,
    store,
    render: h => h(App),
    config: {
        devtools: config.devtool
    },
    mounted() {
        WmsLoader.hide();
        this.$store.watch(this.$store.getters.getLoader, n => {
            if (n > 0) {
                WmsLoader.show();
            } else {
                WmsLoader.hide();
            }
        });
    }
});
